@@ -220,33 +220,72 @@ public:
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
 
-    PendingChannelRequest *ensureStreamedMediaCall(
+    PendingChannelRequest *ensureAudioCall(
+            const QString &contactIdentifier,
+            const QString &initialAudioContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *ensureAudioCall(
+            const ContactPtr &contact,
+            const QString &initialAudioContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *ensureVideoCall(
+            const QString &contactIdentifier,
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *ensureVideoCall(
+            const ContactPtr &contact,
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *ensureAudioVideoCall(
+            const QString &contactIdentifier,
+            const QString &initialAudioContentName = QString(),
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *ensureAudioVideoCall(
+            const ContactPtr &contact,
+            const QString &initialAudioContentName = QString(),
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaCall(
             const QString &contactIdentifier,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *ensureStreamedMediaCall(
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaCall(
             const ContactPtr &contact,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *ensureStreamedMediaAudioCall(
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaAudioCall(
             const QString &contactIdentifier,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *ensureStreamedMediaAudioCall(
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaAudioCall(
             const ContactPtr &contact,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *ensureStreamedMediaVideoCall(
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaVideoCall(
             const QString &contactIdentifier,
             bool withAudio = true,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *ensureStreamedMediaVideoCall(
+    TP_QT_DEPRECATED PendingChannelRequest *ensureStreamedMediaVideoCall(
             const ContactPtr &contact,
             bool withAudio = false,
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
@@ -279,13 +318,26 @@ public:
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
 
-    PendingChannelRequest *createConferenceStreamedMediaCall(
+    PendingChannelRequest *createDBusTube(
+            const QString &contactIdentifier,
+            const QString &serviceName,
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+    PendingChannelRequest *createDBusTube(
+            const ContactPtr &contact,
+            const QString &serviceName,
+            const QDateTime &userActionTime = QDateTime::currentDateTime(),
+            const QString &preferredHandler = QString(),
+            const ChannelRequestHints &hints = ChannelRequestHints());
+
+    TP_QT_DEPRECATED PendingChannelRequest *createConferenceStreamedMediaCall(
             const QList<ChannelPtr> &channels,
             const QStringList &initialInviteeContactsIdentifiers = QStringList(),
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
             const QString &preferredHandler = QString(),
             const ChannelRequestHints &hints = ChannelRequestHints());
-    PendingChannelRequest *createConferenceStreamedMediaCall(
+    TP_QT_DEPRECATED PendingChannelRequest *createConferenceStreamedMediaCall(
             const QList<ChannelPtr> &channels,
             const QList<ContactPtr> &initialInviteeContacts = QList<ContactPtr>(),
             const QDateTime &userActionTime = QDateTime::currentDateTime(),
@@ -338,25 +390,52 @@ public:
             const QString &roomName,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
 
-    PendingChannel *ensureAndHandleStreamedMediaCall(
+    PendingChannel *ensureAndHandleAudioCall(
+            const QString &contactIdentifier,
+            const QString &initialAudioContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *ensureAndHandleAudioCall(
+            const ContactPtr &contact,
+            const QString &initialAudioContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *ensureAndHandleVideoCall(
+            const QString &contactIdentifier,
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *ensureAndHandleVideoCall(
+            const ContactPtr &contact,
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *ensureAndHandleAudioVideoCall(
+            const QString &contactIdentifier,
+            const QString &initialAudioContentName = QString(),
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *ensureAndHandleAudioVideoCall(
+            const ContactPtr &contact,
+            const QString &initialAudioContentName = QString(),
+            const QString &initialVideoContentName = QString(),
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaCall(
             const QString &contactIdentifier,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
-    PendingChannel *ensureAndHandleStreamedMediaCall(
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaCall(
             const ContactPtr &contact,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
 
-    PendingChannel *ensureAndHandleStreamedMediaAudioCall(
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaAudioCall(
             const QString &contactIdentifier,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
-    PendingChannel *ensureAndHandleStreamedMediaAudioCall(
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaAudioCall(
             const ContactPtr &contact,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
 
-    PendingChannel *ensureAndHandleStreamedMediaVideoCall(
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaVideoCall(
             const QString &contactIdentifier,
             bool withAudio = true,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
-    PendingChannel *ensureAndHandleStreamedMediaVideoCall(
+    TP_QT_DEPRECATED PendingChannel *ensureAndHandleStreamedMediaVideoCall(
             const ContactPtr &contact,
             bool withAudio = true,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
@@ -379,6 +458,15 @@ public:
             const QString &service,
             const QDateTime &userActionTime = QDateTime::currentDateTime());
 
+    PendingChannel *createAndHandleDBusTube(
+            const QString &contactIdentifier,
+            const QString &serviceName,
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+    PendingChannel *createAndHandleDBusTube(
+            const ContactPtr &contact,
+            const QString &serviceName,
+            const QDateTime &userActionTime = QDateTime::currentDateTime());
+
     PendingChannel *createAndHandleConferenceTextChat(
             const QList<ChannelPtr> &channels,
             const QList<ContactPtr> &initialInviteeContacts = QList<ContactPtr>(),
@@ -399,11 +487,11 @@ public:
             const QList<ContactPtr> &initialInviteeContacts = QList<ContactPtr>(),
             const QDateTime &userActionTime = QDateTime::currentDateTime());
 
-    PendingChannel *createAndHandleConferenceStreamedMediaCall(
+    TP_QT_DEPRECATED PendingChannel *createAndHandleConferenceStreamedMediaCall(
             const QList<ChannelPtr> &channels,
             const QStringList &initialInviteeContactsIdentifiers = QStringList(),
             const QDateTime &userActionTime = QDateTime::currentDateTime());
-    PendingChannel *createAndHandleConferenceStreamedMediaCall(
+    TP_QT_DEPRECATED PendingChannel *createAndHandleConferenceStreamedMediaCall(
             const QList<ChannelPtr> &channels,
             const QList<ContactPtr> &initialInviteeContacts = QList<ContactPtr>(),
             const QDateTime &userActionTime = QDateTime::currentDateTime());
