@@ -40,39 +40,13 @@
 #include <TelepathyQt/PendingReady>
 #include <TelepathyQt/PendingVariantMap>
 #include <TelepathyQt/Types>
+#include <TelepathyQt/Utils>
 
 #include <QDBusConnectionInterface>
 #include <QQueue>
 #include <QStringList>
 #include <QTimer>
 
-namespace
-{
-
-bool checkValidProtocolName(const QString &protocolName)
-{
-    if (!protocolName[0].isLetter()) {
-        return false;
-    }
-
-    int length = protocolName.length();
-    if (length <= 1) {
-        return true;
-    }
-
-    QChar ch;
-    for (int i = 1; i < length; ++i) {
-        ch = protocolName[i];
-        if (!ch.isLetterOrNumber() && ch != QLatin1Char('-')) {
-            return false;
-        }
-    }
-
-    return true;
-}
-
-}
-
 namespace Tp
 {
 
@@ -1072,12 +1046,17 @@ void ConnectionManager::gotProtocolsLegacy(QDBusPendingCallWatcher *watcher)
         debug() << "Got reply to ConnectionManager.ListProtocols";
         protocolsNames = reply.value();
 
-        foreach (const QString &protocolName, protocolsNames) {
-            mPriv->protocols.append(ProtocolInfo(ConnectionManagerPtr(this), protocolName));
-            mPriv->parametersQueue.enqueue(protocolName);
-        }
+        if (!protocolsNames.isEmpty()) {
+            foreach (const QString &protocolName, protocolsNames) {
+                mPriv->protocols.append(ProtocolInfo(ConnectionManagerPtr(this), protocolName));
+                mPriv->parametersQueue.enqueue(protocolName);
+            }
 
-        mPriv->introspectParametersLegacy();
+            mPriv->introspectParametersLegacy();
+        } else {
+            //no protocols - introspection finished
+            mPriv->readinessHelper->setIntrospectCompleted(FeatureCore, true);
+        }
     } else {
         mPriv->readinessHelper->setIntrospectCompleted(FeatureCore, false, reply.error());
 
