@@ -245,7 +245,7 @@ DBusTubeChannel::~DBusTubeChannel()
 QString DBusTubeChannel::serviceName() const
 {
     if (!isReady(FeatureCore)) {
-        warning() << "DBusTubeChannel::serviceName() used with "
+        warning() << "DBusTubeChannel::service() used with "
             "FeatureCore not ready";
         return QString();
     }
