@@ -80,6 +80,11 @@ Presence Presence::available(const QString &statusMessage)
     return Presence(ConnectionPresenceTypeAvailable, QLatin1String("available"), statusMessage);
 }
 
+Presence Presence::chat(const QString &statusMessage)
+{
+    return Presence(ConnectionPresenceTypeAvailable, QLatin1String("chat"), statusMessage);
+}
+
 Presence Presence::away(const QString &statusMessage)
 {
     return Presence(ConnectionPresenceTypeAway, QLatin1String("away"), statusMessage);
@@ -95,6 +100,11 @@ Presence Presence::busy(const QString &statusMessage)
     return Presence(ConnectionPresenceTypeBusy, QLatin1String("busy"), statusMessage);
 }
 
+Presence Presence::dnd(const QString &statusMessage)
+{
+    return Presence(ConnectionPresenceTypeBusy, QLatin1String("dnd"), statusMessage);
+}
+
 Presence Presence::xa(const QString &statusMessage)
 {
     return Presence(ConnectionPresenceTypeExtendedAway, QLatin1String("xa"), statusMessage);
@@ -167,6 +177,7 @@ QString Presence::statusMessage() const
     return mPriv->sp.statusMessage;
 }
 
+// Sets all fields
 void Presence::setStatus(const SimplePresence &value)
 {
     if (!isValid()) {
@@ -177,6 +188,11 @@ void Presence::setStatus(const SimplePresence &value)
     mPriv->sp = value;
 }
 
+// TODO: explain in proper docs that we don't have setStatusType and setStatus(QString status)
+// separately, because:
+// 1) type and status are tightly related with each other
+// 2) all statuses can't have status message so changing the status alone might make the presence
+// illegal if a message was left around
 void Presence::setStatus(ConnectionPresenceType type, const QString &status,
         const QString &statusMessage)
 {
@@ -190,6 +206,15 @@ void Presence::setStatus(ConnectionPresenceType type, const QString &status,
     mPriv->sp.statusMessage = statusMessage;
 }
 
+void Presence::setStatusMessage(const QString &statusMessage)
+{
+    if (!isValid()) {
+        return;
+    }
+
+    mPriv->sp.statusMessage = statusMessage;
+}
+
 SimplePresence Presence::barePresence() const
 {
     if (!isValid()) {
@@ -238,6 +263,114 @@ PresenceSpec::~PresenceSpec()
 {
 }
 
+PresenceSpec PresenceSpec::available(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeAvailable;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("available"), spec);
+}
+
+PresenceSpec PresenceSpec::chat(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeAvailable;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("chat"), spec);
+}
+
+PresenceSpec PresenceSpec::pstn(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeAvailable;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("pstn"), spec);
+}
+
+PresenceSpec PresenceSpec::away(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeAway;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("away"), spec);
+}
+
+PresenceSpec PresenceSpec::brb(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeAway;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("brb"), spec);
+}
+
+PresenceSpec PresenceSpec::busy(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeBusy;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("busy"), spec);
+}
+
+PresenceSpec PresenceSpec::dnd(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeBusy;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("dnd"), spec);
+}
+
+PresenceSpec PresenceSpec::xa(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeExtendedAway;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("xa"), spec);
+}
+
+PresenceSpec PresenceSpec::hidden(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeHidden;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("hidden"), spec);
+}
+
+PresenceSpec PresenceSpec::offline(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeOffline;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("offline"), spec);
+}
+
+PresenceSpec PresenceSpec::unknown(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeUnknown;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("unknown"), spec);
+}
+
+PresenceSpec PresenceSpec::error(PresenceSpec::SimpleStatusFlags flags)
+{
+    SimpleStatusSpec spec;
+    spec.type = ConnectionPresenceTypeError;
+    spec.maySetOnSelf = flags & MaySetOnSelf;
+    spec.canHaveMessage = flags & CanHaveStatusMessage;
+    return PresenceSpec(QLatin1String("error"), spec);
+}
+
 PresenceSpec &PresenceSpec::operator=(const PresenceSpec &other)
 {
     this->mPriv = other.mPriv;
