@@ -4,16 +4,16 @@
 
 #include <tests/lib/glib/echo2/conn.h>
 
-#include <TelepathyQt4/Account>
-#include <TelepathyQt4/AccountManager>
-#include <TelepathyQt4/AccountSet>
-#include <TelepathyQt4/ConnectionCapabilities>
-#include <TelepathyQt4/PendingAccount>
-#include <TelepathyQt4/PendingOperation>
-#include <TelepathyQt4/PendingReady>
-#include <TelepathyQt4/PendingStringList>
-#include <TelepathyQt4/PendingVoid>
-#include <TelepathyQt4/Profile>
+#include <TelepathyQt/Account>
+#include <TelepathyQt/AccountManager>
+#include <TelepathyQt/AccountSet>
+#include <TelepathyQt/ConnectionCapabilities>
+#include <TelepathyQt/PendingAccount>
+#include <TelepathyQt/PendingOperation>
+#include <TelepathyQt/PendingReady>
+#include <TelepathyQt/PendingStringList>
+#include <TelepathyQt/PendingVoid>
+#include <TelepathyQt/Profile>
 
 #include <telepathy-glib/debug.h>
 
@@ -60,6 +60,7 @@ private:
     Tp::AccountManagerPtr mAM;
     TestConnHelper *mConn;
     int mAccountsCount;
+    bool mCreatingAccount;
 
     QHash<QString, QVariant> mProps;
 };
@@ -111,7 +112,9 @@ void TestAccountBasics::onNewAccount(const Tp::AccountPtr &acc)
     Q_UNUSED(acc);
 
     mAccountsCount++;
-    mLoop->exit(0);
+    if (!mCreatingAccount) {
+        mLoop->exit(0);
+    }
 }
 
 TEST_IMPLEMENT_PROPERTY_CHANGE_SLOT(const QString &, ServiceName)
@@ -168,6 +171,7 @@ void TestAccountBasics::initTestCase()
 void TestAccountBasics::init()
 {
     mProps.clear();
+    mCreatingAccount = false;
 
     initImpl();
 }
@@ -194,7 +198,9 @@ void TestAccountBasics::testBasics()
     QVERIFY(connect(pacc,
                     SIGNAL(finished(Tp::PendingOperation *)),
                     SLOT(expectSuccessfulCall(Tp::PendingOperation *))));
+    mCreatingAccount = true;
     QCOMPARE(mLoop->exec(), 0);
+    mCreatingAccount = false;
     QVERIFY(pacc->account());
 
     while (mAccountsCount != 1) {
@@ -205,7 +211,7 @@ void TestAccountBasics::testBasics()
     QStringList paths;
     QString accPath(QLatin1String("/org/freedesktop/Telepathy/Account/foo/bar/Account0"));
     QCOMPARE(pathsForAccounts(mAM->allAccounts()), QStringList() << accPath);
-    QList<AccountPtr> accs = mAM->accountsForPaths(
+    QList<AccountPtr> accs = mAM->accountsForObjectPaths(
             QStringList() << accPath << QLatin1String("/invalid/path"));
     QCOMPARE(accs.size(), 2);
     QCOMPARE(accs[0]->objectPath(), accPath);
@@ -357,7 +363,9 @@ void TestAccountBasics::testBasics()
     QVERIFY(connect(pacc,
                     SIGNAL(finished(Tp::PendingOperation *)),
                     SLOT(expectSuccessfulCall(Tp::PendingOperation *))));
+    mCreatingAccount = true;
     QCOMPARE(mLoop->exec(), 0);
+    mCreatingAccount = false;
 
     while (mAccountsCount != 2) {
         QCOMPARE(mLoop->exec(), 0);
@@ -513,7 +521,7 @@ void TestAccountBasics::testBasics()
     // simulate that the account has a connection
     QVERIFY(connect(new PendingVoid(
                         accPropertiesInterface->Set(
-                            QLatin1String(TELEPATHY_INTERFACE_ACCOUNT),
+                            TP_QT_IFACE_ACCOUNT,
                             QLatin1String("Connection"),
                             QDBusVariant(mConn->objectPath())),
                         acc),
@@ -553,7 +561,7 @@ void TestAccountBasics::testBasics()
     mProps.clear();
     QVERIFY(connect(new PendingVoid(
                         accPropertiesInterface->Set(
-                            QLatin1String(TELEPATHY_INTERFACE_ACCOUNT),
+                            TP_QT_IFACE_ACCOUNT,
                             QLatin1String("Connection"),
                             QDBusVariant(QLatin1String("/"))),
                         acc),
