@@ -554,7 +554,7 @@ void TestAccountChannelDispatcher::init()
 
     mChanPath.clear();
     mChanProps.clear();
-    mFilePath = QDir::currentPath() + QLatin1String("/test-account-channel-dispatcher");
+    mFilePath = QCoreApplication::applicationFilePath();
 }
 
 void TestAccountChannelDispatcher::testPCR(PendingChannelRequest *pcr)
@@ -1069,8 +1069,6 @@ void TestAccountChannelDispatcher::testCreateAndHandleChannelHandledAgain()
                 "handle", handle,
                 NULL));
 
-    tp_handle_unref(contactRepo, handle);
-
     PendingChannel *pcOut = 0;
     TEST_CREATE_ENSURE_AND_HANDLE_CHANNEL(createAndHandleChannel, false, false, true, "", 0, &pcOut);
 
