@@ -167,9 +167,6 @@ constructed (GObject *object)
   if (chain_up != NULL)
     chain_up (object);
 
-  tp_handle_ref (contact_repo, self->priv->handle);
-  tp_handle_ref (contact_repo, self->priv->initiator);
-
   tp_dbus_daemon_register_object (
       tp_base_connection_get_dbus_daemon (self->priv->conn),
       self->priv->object_path, self);
@@ -490,11 +487,6 @@ static void
 finalize (GObject *object)
 {
   ExampleCallableMediaChannel *self = EXAMPLE_CALLABLE_MEDIA_CHANNEL (object);
-  TpHandleRepoIface *contact_handles = tp_base_connection_get_handles
-      (self->priv->conn, TP_HANDLE_TYPE_CONTACT);
-
-  tp_handle_unref (contact_handles, self->priv->handle);
-  tp_handle_unref (contact_handles, self->priv->initiator);
 
   g_free (self->priv->object_path);
 
@@ -558,7 +550,7 @@ add_member (GObject *object,
     }
 
   /* Otherwise it's a meaningless request, so reject it. */
-  g_set_error (error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+  g_set_error (error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
       "Cannot add handle %u to channel", member);
   return FALSE;
 }
@@ -805,7 +797,7 @@ media_remove_streams (TpSvcChannelTypeStreamedMedia *iface,
       if (g_hash_table_lookup (self->priv->streams,
             GUINT_TO_POINTER (id)) == NULL)
         {
-          GError *error = g_error_new (TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          GError *error = g_error_new (TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
               "No stream with ID %u in this channel", id);
 
           dbus_g_method_return_error (context, error);
@@ -838,14 +830,14 @@ media_request_stream_direction (TpSvcChannelTypeStreamedMedia *iface,
 
   if (stream == NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "No stream with ID %u in this channel", stream_id);
       goto error;
     }
 
   if (stream_direction > TP_MEDIA_STREAM_DIRECTION_BIDIRECTIONAL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "Stream direction %u is not valid", stream_direction);
       goto error;
     }
@@ -1057,6 +1049,7 @@ example_callable_media_channel_add_stream (ExampleCallableMediaChannel *self,
       "handle", self->priv->handle,
       "type", media_type,
       "locally-requested", locally_requested,
+      "simulation-delay", self->priv->simulation_delay,
       NULL);
 
   g_hash_table_insert (self->priv->streams, GUINT_TO_POINTER (id), stream);
@@ -1118,7 +1111,7 @@ media_request_streams (TpSvcChannelTypeStreamedMedia *iface,
 
   if (contact_handle != self->priv->handle)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "This channel is for handle #%u, we can't make a stream to #%u",
           self->priv->handle, contact_handle);
       goto error;
@@ -1126,7 +1119,7 @@ media_request_streams (TpSvcChannelTypeStreamedMedia *iface,
 
   if (self->priv->progress == PROGRESS_ENDED)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "Call has terminated");
       goto error;
     }
@@ -1141,7 +1134,7 @@ media_request_streams (TpSvcChannelTypeStreamedMedia *iface,
         case TP_MEDIA_STREAM_TYPE_VIDEO:
           break;
         default:
-          g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+          g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
               "%u is not a valid Media_Stream_Type", media_type);
           goto error;
         }
@@ -1310,7 +1303,7 @@ hold_request_hold (TpSvcChannelInterfaceHold *iface,
 
   if (!hold && strstr (peer, "(no unhold)") != NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "unable to unhold");
       goto error;
     }
@@ -1384,7 +1377,7 @@ dtmf_start_tone (TpSvcChannelInterfaceDTMF *iface,
 
   if (stream == NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "No stream with ID %u in this channel", stream_id);
       goto error;
     }
@@ -1392,7 +1385,7 @@ dtmf_start_tone (TpSvcChannelInterfaceDTMF *iface,
   g_object_get (G_OBJECT (stream), "type", &media_type, NULL);
   if (media_type != TP_MEDIA_STREAM_TYPE_AUDIO)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "DTMF is only supported by audio streams");
       goto error;
     }
@@ -1422,7 +1415,7 @@ dtmf_stop_tone (TpSvcChannelInterfaceDTMF *iface,
 
   if (stream == NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "No stream with ID %u in this channel", stream_id);
       goto error;
     }
@@ -1430,7 +1423,7 @@ dtmf_stop_tone (TpSvcChannelInterfaceDTMF *iface,
   g_object_get (G_OBJECT (stream), "type", &media_type, NULL);
   if (media_type != TP_MEDIA_STREAM_TYPE_AUDIO)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+      g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
           "DTMF is only supported by audio streams");
       goto error;
     }
@@ -1438,7 +1431,7 @@ dtmf_stop_tone (TpSvcChannelInterfaceDTMF *iface,
   peer = tp_handle_inspect (contact_repo, self->priv->handle);
   if (strstr (peer, "(no continuous tone)") != NULL)
     {
-      g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "Continuous tones are not supported by this stream");
       goto error;
     }
