@@ -120,8 +120,6 @@ constructed (GObject *object)
   TpHandleRepoIface *contact_repo = tp_base_connection_get_handles
       (self->priv->conn, TP_HANDLE_TYPE_CONTACT);
   TpHandle self_handle = self->priv->conn->self_handle;
-  TpHandleRepoIface *handle_repo = tp_base_connection_get_handles
-      (self->priv->conn, self->priv->handle_type);
 
   if (chain_up != NULL)
     chain_up (object);
@@ -133,7 +131,6 @@ constructed (GObject *object)
       tp_base_connection_get_dbus_daemon (self->priv->conn),
       self->priv->object_path, self);
 
-  tp_handle_ref (handle_repo, self->priv->handle);
   tp_group_mixin_init (object, G_STRUCT_OFFSET (ExampleContactListBase, group),
       contact_repo, self_handle);
   /* Both the subclasses have full support for telepathy-spec 0.17.6. */
@@ -166,10 +163,14 @@ list_constructed (GObject *object)
           TP_CHANNEL_GROUP_FLAG_CAN_REMOVE, 0);
       break;
     case EXAMPLE_CONTACT_LIST_STORED:
+    case EXAMPLE_CONTACT_LIST_DENY:
       /* We can add people to our roster (not that that's very useful without
        * also adding them to subscribe), and we can remove them altogether
        * (which implicitly removes them from subscribe, publish, and all
        * user-defined groups).
+       *
+       * Similarly, we can block and unblock people (i.e. add/remove them
+       * to/from the deny list)
        */
       tp_group_mixin_change_flags (object,
           TP_CHANNEL_GROUP_FLAG_CAN_ADD | TP_CHANNEL_GROUP_FLAG_CAN_REMOVE, 0);
@@ -341,10 +342,7 @@ static void
 finalize (GObject *object)
 {
   ExampleContactListBase *self = EXAMPLE_CONTACT_LIST_BASE (object);
-  TpHandleRepoIface *handle_repo = tp_base_connection_get_handles
-      (self->priv->conn, self->priv->handle_type);
 
-  tp_handle_unref (handle_repo, self->priv->handle);
   g_free (self->priv->object_path);
   tp_group_mixin_finalize (object);
 
@@ -533,7 +531,7 @@ static void
 list_channel_close (TpSvcChannel *iface G_GNUC_UNUSED,
                     DBusGMethodInvocation *context)
 {
-  GError e = { TP_ERRORS, TP_ERROR_NOT_IMPLEMENTED,
+  GError e = { TP_ERROR, TP_ERROR_NOT_IMPLEMENTED,
       "ContactList channels with handle type LIST may not be closed" };
 
   dbus_g_method_return_error (context, &e);
@@ -548,7 +546,7 @@ group_channel_close (TpSvcChannel *iface,
 
   if (tp_handle_set_size (base->group.members) > 0)
     {
-      GError e = { TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+      GError e = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
           "Non-empty groups may not be deleted (closed)" };
 
       dbus_g_method_return_error (context, &e);
